"""
Import hgfind for ease of importing from package

"""
from .hgfind import WrongGeneName, hgfind
